/*
Author: Sjors Hettinga
	based on the examples in datasheets of the RFM01 and RFM02
Date: 30-11-2010
Hardware: ATmega88, met RFM01 en RFM02 modules
Description: This are the prototypes of the driver functions for the transmitter and receiver
	The driver has to handle all the harware (SPI, I/O pins en external interrupts)
*/

/* Initiation,
This function configures the following hardware parts for the communication 
with the sender and receiver module:
	- I/O ports
	- SPI
	- External interrups
	- Local variables */
void initPHY(void);

/* set functions voor de event handlers
	These functions receive a function pointer, 
	pointing to the function that should be called at an event
*/
// sets the function that has to be executed when the sender requires a new byte
void setDataFeeder(unsigned char (*dataFeed)(void) );
// sets the function that has to be executed when the receiver has new data
void setDataReceiver(void (*dataReceiver)(unsigned char) );


/* Start data transmission
- This function starts the transmission on the RFM02 module
- Also gets the first byte to receive
- Also configures the required local variables
*/
void startTx(void);

/* Stops transmission
This function lets the transmitter (RFM02 module) stop sendingn
*/
void stopTx(void);

/* FIFO reset
	After a data sequence had been received this can be used to reset the receiver
	New data is only offered after the recognision sequence has been received.mt.
*/
void resetRxFIFO();
